<?php
/**
 * minimalblog Theme Customizer
 *
 * @package minimalblog
 */
/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function minimalblog_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'minimalblog_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'minimalblog_customize_partial_blogdescription',
			)
		);
	}
}
add_action( 'customize_register', 'minimalblog_customize_register' );
/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function minimalblog_customize_partial_blogname() {
	 bloginfo( 'name' );
}
/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function minimalblog_customize_partial_blogdescription() {
	bloginfo( 'description' );
}
/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function minimalblog_customize_preview_js() {
	wp_enqueue_script( 'minimalblog-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'minimalblog_customize_preview_js' );
// Customize function.
if ( ! function_exists( 'minimalblog_customize_name_panel_section' ) ) {
	add_action( 'customize_register', 'minimalblog_customize_name_panel_section' );
	/**
	 *
	 * minimalblog customize name panel section
	 */
	function minimalblog_customize_name_panel_section( $wp_customize ) {
		/**
		 * Multiple select customize control class.
		 */
		class minimalblog_Customize_Control_Multiple_Select extends WP_Customize_Control {
				/**
				 * The type of customize control being rendered.
				 */
			public $type = 'multiple-select';
				/**
				 * Displays the multiple select on the customize screen.
				 */
			public function render_content() {
				if ( empty( $this->choices ) ) {
					return;
				}
				?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<select <?php $this->link(); ?> multiple="multiple" style="height: 100%;">
				<?php
				$i = 0;
				foreach ( $this->choices as $value => $label ) {
					$i++;
					$selected = ( in_array( $value, $this->value() ) ) ? selected( 1, 1, false ) : selected( 0, 0, true );
					echo '<option value="' . esc_attr( $value ) . '"' . $selected . '>' . $label . '</option>';
				}
				?>
				</select>
			</label>
				<?php
			}
		}
	if( ! class_exists( 'Minimalblog_Note_Control' ) ){

		class Minimalblog_Note_Control extends WP_Customize_Control {

			public function render_content(){ ?>
	    	    <span class="customize-control-title">
	    			<?php echo wp_kses_post( $this->label ); ?>
	    		</span>

	    		<?php if( $this->description ){ ?>
	    			<span class="description customize-control-description">
	    			<?php echo wp_kses_post( $this->description ); ?>
	    			</span>
	    		<?php }
	        }
		}
	}

	class Minimalblog_Customize_Control_Separetor extends WP_Customize_Control {
	    /**
	     * The type of customize control being rendered.
	     */
	    public $type = 'sepearetor';
	    /**
	     * Displays the multiple select on the customize screen.
	     */
	    public function render_content() {
	    ?>
	    <hr>
	        <h4 style="text-align: center; text-transform: uppercase;"><?php echo esc_html( $this->label ); ?></h4>
	    <hr>
	    <?php }
	}


	// function minimalblog_customize_control_separetor($wp_customize, $sepearetor_id_name, $sepearetor_name, $section_name){
	// 	$wp_customize->add_setting(
	// 	$sepearetor_id_name,
	// 		array(
	// 			'default'            => true,
	// 			'transport'            => 'refresh',
	// 			'capability'           => 'edit_theme_options',
	// 			'senitize_callback' => 'sanitize_text_field',
	// 		)
	// 	);

	// 	$wp_customize->add_control(
	// 		new Minimalblog_Customize_Control_Separetor($wp_customize,
	// 		$sepearetor_id_name,
	// 		array(
	// 			'label'       => esc_html($sepearetor_name),
	// 			'section'     => $section_name,
	// 			'type'        => 'sepearetor',
	// 		)
	// 	));
	// }

		$wp_customize->add_panel(
			'minimalblog',
			array(
				'priority'       => 50,
				'title'          => __( 'Minimalblog Settings', 'minimalblog' ),
				'capability'     => 'edit_theme_options',
			)
		);

		require get_theme_file_path( 'inc/themeoptions/header-options.php' );
		require get_theme_file_path( 'inc/themeoptions/sticky-sidebar.php' );
		require get_theme_file_path( 'inc/themeoptions/banner-options.php' );
		require get_theme_file_path( 'inc/themeoptions/social-links.php' );
		require get_theme_file_path( 'inc/themeoptions/featured-options.php' );
		require get_theme_file_path( 'inc/themeoptions/category-slider.php' );
		require get_theme_file_path( 'inc/themeoptions/footer-options.php' );
		require get_theme_file_path( 'inc/themeoptions/blog-options.php' );
		require get_theme_file_path( 'inc/themeoptions/typography.php' );
		require get_theme_file_path( 'inc/themeoptions/preloader.php' );
		require get_theme_file_path( 'inc/themeoptions/contact.php' );
		require get_theme_file_path( 'inc/themeoptions/colors.php' );
	}
}
