<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Minimal Blog
 */
/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function minimalblog_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	$classes[] = 'preloader-wrapper';
	$get_border_box_shadow = get_theme_mod( 'border_box_shadow_show_hide', true );
	if ( false == $get_border_box_shadow ) {
		$classes[] = 'border_and_box_shadow_hide';
	}
	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}
	return $classes;
}
add_filter( 'body_class', 'minimalblog_body_classes' );
/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function minimalblog_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'minimalblog_pingback_header' );
if ( ! function_exists( 'minimalblog_comment_list' ) ) :
	/**
	 * Template for comments and pingbacks.
	 *
	 * Used as a callback by wp_list_comments() for displaying the comments.
	 *
	 * @since Shape 1.0
	 */
	function minimalblog_comment_list( $comment, $args, $depth ) {
		extract( $args, EXTR_SKIP );
		if ( 'div' == $args['style'] ) {
			$tag = 'div';
			$add_below = 'comment';
		} else {
			$tag = 'li';
			$add_below = 'div-comment';
		}
		?>
  <<?php echo esc_attr( $tag ); ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID(); ?>">
		<?php if ( 'div' == $args['style'] ) : ?>
  <div id="div-comment-<?php comment_ID(); ?>" class="comment-body review-list">
	<?php endif; ?>
	<div class="single-comment">
		<div class="commenter-image">
			<?php
			if ( 0 != $args['avatar_size'] ) {
				echo get_avatar( $comment, $args['avatar_size'] );}
			?>
		</div>
		<div class="commnenter-details">
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'minimalblog' ); ?></em>
			<br />
		<?php endif; ?>
			<h4><?php printf( wp_kses_post( '%s', 'minimalblog' ), sprintf( '%s', get_comment_author_link() ) ); ?></h4>
			<div class="comment-time">
				<p><time datetime="<?php comment_time( 'c' ); ?>">
								<?php
									/* translators: 1: comment date, 2: comment time */
									printf( wp_kses_post( '%1$s at %2$s', 'minimalblog' ), get_comment_date( '', $comment ), get_comment_time() );
								?>
							</time></p>
			</div>
				<?php comment_text(); ?>
				<?php
				comment_reply_link(
					array_merge(
						$args,
						array(
							'depth'     => $depth,
							'max_depth' => $args['max_depth'],
							'before'    => '<div class="reply">',
							'after'     => '</div>',
						)
					)
				);
				?>
		</div>
	</div>
		<?php if ( 'div' == $args['style'] ) : ?>
  </div>
			<?php
  endif;
	}
endif; // ends check for minimalblog_comment_list()
function minimalblog_user_meta( $usermeta ) {
	$usermeta['facebook'] = __( 'Facebook', 'minimalblog' );
	$usermeta['twitter'] = __( 'Twitter', 'minimalblog' );
	$usermeta['linkedin'] = __( 'Linkedin', 'minimalblog' );
	$usermeta['youtube'] = __( 'Youtube', 'minimalblog' );
	return $usermeta;
}

function minimalblog_get_excerpt( $limit, $source = null ) {
	( $source == 'content' ? ( $excerpt = get_the_content() ) : ( $excerpt = get_the_excerpt() ) );
	$excerpt = preg_replace( ' (\[.*?\])', '', $excerpt );
	$excerpt = strip_shortcodes( $excerpt );
	$excerpt = strip_tags( $excerpt );
	$excerpt = substr( $excerpt, 0, $limit );
	$excerpt = substr( $excerpt, 0, strripos( $excerpt, ' ' ) );
	$excerpt = trim( preg_replace( '/\s+/', ' ', $excerpt ) );
	return $excerpt;
}
if ( ! function_exists( 'minimalblog_footer_credit' ) ) {
	function minimalblog_footer_credit() {
		$credit = '<strong>&nbsp;&nbsp;</strong>'.esc_html__('Theme By ', 'minimalblog').'<a href="'.esc_url( 'https://www.graphicxtreme.com/' ).'"> '.esc_html__( 'Graphicxtreme', 'minimalblog' ).'</span></a>';
		return $credit;
	}
}
function minimalblog_author_vcard() {
	?>
	<div class="author-vcard">
		<div class="author-vcard__image">
			<?php
			echo get_avatar( get_the_author_meta( 'ID' ), 100, '', '', null );
			?>
		</div>
		<div class="author-vcard__about">
			<h4>
			<?php
			$desc = get_the_author_meta( 'description' );
			 echo get_the_author_meta( 'nickname' );
			?>
			 </h4>
			<?php if ( ! empty( $desc ) ) : ?>
				<p><?php echo wp_kses_post( $desc ); ?></p>
			<?php endif; ?>

			<p>
			<?php
			$userpost_count = count_user_posts( get_the_author_meta( 'ID' ), 'post', false );
			if ( $userpost_count > 1 ) {
				$numberingtext = 'posts';
			} else {
				$numberingtext = 'post';
			}
			$userposts = 'the user has only %1$s %2$s';
			printf( esc_html( $userposts ), $userpost_count, $numberingtext );
			?>
			 </p>
		</div>
	</div>
	<?php
	return;
}


/**
 * Adding Getting Started Page in admin menu
 */
function minimalblog_admin_notice() {
    global $pagenow;
    $theme_args      = wp_get_theme();
    $meta            = get_option( 'minimalblog-update-notice' );
    $name            = $theme_args->__get( 'Name' );
    $current_screen  = get_current_screen();


        if ( is_network_admin() ) {
            return;
        }

        if ( ! current_user_can( 'manage_options' ) ) {
            return;
        } ?>
        <div class="welcome-message notice notice-info">
            <div class="notice-wrapper">
                <div class="notice-text">
                    <h3><?php esc_html_e( 'Congratulations!', 'minimalblog' ); ?></h3>
                    <p><?php printf( __( 'Minimal Blog is now installed and ready to use. Click the links below to get started.', 'minimalblog' ), esc_html( $name ) ) ; ?></p>
                    <p><a href="<?php echo esc_url( 'https://www.smarterthemes.com/theme-minimal-blog-pro/' );?>" class="button button-primary" style="text-decoration: none;" target="_blank"><?php esc_html_e( 'Watch this video to get started.', 'minimalblog' ); ?></a></p>
                    <p class="dismiss-link"><strong><a href="?minimalblog-update-notice=1"><?php esc_html_e( 'Dismiss','minimalblog' ); ?></a></strong></p>
                </div>
            </div>
        </div>
    <?php
}

add_action( 'admin_notices', 'minimalblog_admin_notice' );


/*
 * Minimalblog Page Sidebar Control
 */
add_action('minimalblog_page_column_before', 'minimalblog_page_column_wrapper_start');
function minimalblog_page_column_wrapper_start(){
	if (is_single()) {
		$minimalblog_get_sidebar_align = get_theme_mod( 'blog_single_page_sidebar', 'right' );
	}else{
		$minimalblog_get_sidebar_align = get_theme_mod( 'blog_page_sidebar', 'right' );
	}
	$minimalblog_page_content_col = 'col-md-7 col-lg-8 order-0';
	if ( $minimalblog_get_sidebar_align === 'right' ) {
		$minimalblog_page_content_col = 'col-md-7 col-lg-8 order-0';
	} elseif ( $minimalblog_get_sidebar_align === 'left' ) {
		$minimalblog_page_content_col = 'col-md-7 col-lg-8 order-1';
	} elseif ( $minimalblog_get_sidebar_align === 'no' ) {
		$minimalblog_page_content_col = 'col-md-12';
	} else {
		$minimalblog_page_content_col = 'col-md-7 col-lg-8 order-0';
	}

	?>
	<div class="container">
		<div class="row wrapper-content">
			<div class="<?php echo esc_attr( $minimalblog_page_content_col ); ?>">
	<?php
}

add_action('minimalblog_page_column_after', 'minimalblog_page_column_wrapper_end');
function minimalblog_page_column_wrapper_end(){
	if (is_single()) {
		$minimalblog_get_sidebar_align = get_theme_mod( 'blog_single_page_sidebar', 'right' );
	}else{
		$minimalblog_get_sidebar_align = get_theme_mod( 'blog_page_sidebar', 'right' );
	}
	$minimalblog_page_sidebar_col = 'col-md-5 col-lg-4 order-1';
	$minimalblog_page_sidebar_on_off = true;
	if ( $minimalblog_get_sidebar_align === 'right' ) {
		$minimalblog_page_sidebar_col = 'col-md-5 col-lg-4 order-1';
		$minimalblog_page_sidebar_on_off = true;
	} elseif ( $minimalblog_get_sidebar_align === 'left' ) {
		$minimalblog_page_sidebar_col = 'col-md-5 col-lg-4 order-0';
		$minimalblog_page_sidebar_on_off = true;
	} elseif ( $minimalblog_get_sidebar_align === 'no' ) {
		$minimalblog_page_sidebar_col = 'sidebar-hide';
		$minimalblog_page_sidebar_on_off = false;
	} else {
		$minimalblog_page_sidebar_col = 'col-md-5 col-lg-4 order-1';
	}
	?>
			</div>
			<?php if ( $minimalblog_page_sidebar_on_off === true ) : ?>
				<div class="<?php echo esc_attr( $minimalblog_page_sidebar_col ); ?>">
						<?php get_sidebar(); ?>
				</div>
			<?php endif; ?>
		</div>
	</div>
	<?php
}